# scaledown
Scaledown Package

# Contributing
Contributions to ScaleDown are welcome! You can contribute to ScaleDown in 4 different ways:
- Request for Hardware
- Write Content and Create Learning Resources
- Documentation and Research
- Add Features and Fix Issues

You can find detailed contribution guideline [here](contributing.md)
